function [Moments]=Lmz2MomF(Lmz,varargin);
%Lmz2MomF  Fast algorithm for enumerating moments from Lmz
%   [Moments] = Lmz2MomS(LmzA,varargin) returns varargin number of moments 
%   
%   If varargin is left blank then 4 moments are returned
%
%   Input : LmzA, varargin
%   Output: Moments
%   
%   Notation: Lmz is the bivariate polynomial satisfied by the Stieltjes
%   transform (see definiton in reference below)
%
%   Note: First moment should equal 1 
%
%   Comment: Sometimes more than one set of "moments" may be enumerated. 
%   Positivity arguments will have to be used to identify the right one.
%
%   Dependencies: Requires EXTENDED Symbolic Toolbox
%   
%   Example:
%       syms m z c
%       LmzA = wishartpol(c) %% Wishart with parameter 0.5
%       Moments = Lmz2MomF(LmzA,6);
%       pretty(Moments)
%       
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Thursday, January 18, 2006.

syms m myu z

Moments=[];

if(isempty(varargin)), 
    max_moment=4; 
else 
    max_moment=varargin{1}; 
end

Lmyuz = Lmz2Lmyuz(Lmz);

MomentSeries = maple('gfun[algeqtoseries]',Lmyuz,z,myu,max_moment,'pos_slopes');

if (length(MomentSeries)==1)
    for idx = 1 : max_moment,
	   Moments = [Moments; maple('coeff',MomentSeries,z,idx-1)];
    end
else
    Moments = MomentSeries;

end



    
