function [Moments] = Lmz2MomS(Lmz,varargin);
%Lmz2MomS  Slow algorithm for enumerating moments from Lmz
%   [Moments] = Lmz2MomS(LmzA,varargin) returns varargin number of moments 
%   
%   If varargin is left blank then 4 moments are returned
%
%   Input : LmzA, varargin
%   Output: Moments
%   
%   Notation: Lmz is the bivariate polynomial satisfied by the Stieltjes
%   transform (see definiton in reference below)
%
%   Comment: If there is more than seemingly valid moment sequence, all are enumerated.
%   Positivity arguments can be used to isolate the correct sequence.
%
%
%   Example:
%       syms m z c
%       LmzA = wishartpol(c) %% Wishart with parameter c
%       Moments = Lmz2MomS(LmzA,6);
%       pretty(Moments)
%       
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Thursday, January 18, 2006.

syms m myu z

if(isempty(varargin)), 
    max_moment=4; 
else 
    max_moment=varargin{1}; 
end

Lmyuz = Lmz2Lmyuz(Lmz);

moment_i = solve(subs(Lmyuz,z,0),myu);
ii = find(moment_i==sym(1));

if (length(ii) == 0)
    warning('No moments exist. The bivariate polynomial does not encode a valid probability measure. ');
    Moments = [];
    return
end


Lmyuz = irreducLuv(subs(Lmyuz,myu,1+myu*z),myu,z);
Lmyuz_z0 = subs(Lmyuz,z,0);
Dmyu = maple('degree',Lmyuz_z0,myu);

if (Dmyu == sym(0));
    Moments = [1;NaN*ones(length(max_moment,1))];
    warning('No moments exist. The bivariate polynomial either does not encode a valid probability measure or the measure is non-compact.');
return;
 

else
   moment_i = solve(Lmyuz_z0,myu);
end

Moments =[];

validexpansion = ones(length(moment_i),1);
for mom_idx = 1 : length(moment_i),
    
    Moment_idx = [];
    Lmyuz_i = Lmyuz;
    moment_idx = moment_i(mom_idx);
    
    for idx = 1 : max_moment,
        
        if(validexpansion(mom_idx)==1)
        
            Moment_idx = [Moment_idx;moment_idx];
            Lmyuz_i = irreducLuv(subs(Lmyuz_i,myu,moment_idx+myu*z),myu,z);
        
            Lmyuz_i_z0 = subs(Lmyuz_i,z,0);
            Dmyu_i = maple('degree',Lmyuz_i_z0,myu);
            
            if(Dmyu_i == sym(0))
                Moment_idx = [];
                validexpansion(mom_idx) = 0;
            else
                moment_idx = solve(Lmyuz_i_z0,myu);
            end
            
        end
    
    end
     
    if(validexpansion(mom_idx)==1),
        Moments = [Moments Moment_idx];
    end

end

[rows,columns] = size(Moments);

if (rows == 0)
     Moments = [1; NaN*ones(max_moment,1)];
    warning('No moments exist. The bivariate polynomial either does not encode a valid probability measure or the measure is non-compact.');
  
    return
elseif (columns > 1)
    warning(['There are ' num2str(columns) ' expansions about zero with initial coefficent equal to 1. All have been returned. Eliminate some or all of them by positivity arguments.']);
    Moments = [ones(1,columns); Moments];
else
    Moments = [1;Moments];
end

    

