function [pdfinfo] = Lmz2pdf(Lmz,varargin);
%Lmz2pdf  Plots the algebraic curve of equation Lmz(m,z) = 0
%   [pdfinfo] = Lmz2pdf(LmzA,xx) returns the real and imaginary roots of
%   LmzA evaluated over the points in the vector xx
%
%   Input : LmzA, xx (vector - optional)
%   Output: xx (vector), pdfinfo (structure) 
%     
%   Structure: pdfinfo
%   Fields   : range (ranger over which density is computed)
%            : density (normalized imaginary part for all the roots == probability density)
%            : real (real part of the algebraic curve)
%            : poles (locations of poles)
%            : multiplepoints (locations of multiple points == Possible Boundary Points)
%            : mean (First moment of the pdf)
%
%
%   Notation: Lmz is the bivariate polynomial satisfied by the Stieltjes
%   transform (see definiton in reference below)
%
%   Usage: plot(pdfinfo.range,pdfinfo.density) will plot the (normalized) imaginary roots --
%   one of them corresponds to the true density.
%
%   Comment: When the degree of the polynomial is greater than 3,
%   additional intervention might be needed to plot the "right root". See
%   reference below for some tips on how to isolate it. 
%
%
%   Open Problem: Developing an efficient "root-tracing" algorithm would be 
%   very useful. If you have any suggestions email raj@mit.edu   
%
%   Example:
%       syms m z 
%       LmzA = wishartpol(0.5) %% Wishart with parameter 0.5
%       pdfinfo = Lmz2pdf(LmzA,[-3:0.01:3]);
%       plot(pdfinfo.range,pdfinfo.density))
%       pdfinfo.multiplepoints 
%       pdfinfo.mean
%  
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Wednesday, January 17, 2006.


syms m z

symsinLmz = findsym(Lmz);


symsinLmz_mz = find((symsinLmz =='m') | (symsinLmz =='z'));
symsinLmz_notmz = find((symsinLmz~='m') & (symsinLmz~='z') & (symsinLmz~=' ') & (symsinLmz~=','));

if (length(symsinLmz_mz) < 2) 
    
    warning(['Input argument Lmz =' char(Lmz) ' is not a polynomial in m and z']);
    root =[];
    return
    
elseif (length(symsinLmz_notmz)>0)
        
    warning(['Input argument Lmz has symbolic variables other than m and z. Setting extra argument(s) ' [char(symsinLmz(symsinLmz_notmz))] ' to 0.5']);
    
    for syms_idx = 1 : length(symsinLmz_notmz),
        Lmz = subs(Lmz,symsinLmz(symsinLmz_notmz(syms_idx)),0.5);
    end
end
   

Dm = double(maple('degree',Lmz,m));


lDmz = maple('coeff',Lmz,m,Dm);

if (maple('degree',lDmz,z)==0)
     poles = [];
else 
     poles = double(solve(lDmz,z));
end

discrimLmz = maple('discrim',Lmz,m);


if(maple('degree',discrimLmz,z) == 0),
    PossBdryPts = [];     
    warning('Possibly atomic measure encoded by the bivariate polynomial. Examine pdfinfo.poles and pdfinfo.real.');
else
    PossBdryPts = double(solve(discrimLmz,z));
    PossBdryPts = PossBdryPts(imag(PossBdryPts)==0);
end



[Moments] = Lmz2MomS(Lmz,2);
if (length(Moments)==0)
     pdf  = [];
     warning('Bivariate polynomial entered does not correspond to a valid probability measure');
     return
else
    Moment1 = Moments(2,:);
end

if(nargin == 1),     
    xmin = min([PossBdryPts;poles]) - 1;
    xmax = max([PossBdryPts;poles]) + 1;
    step_size =  min((xmax-xmin)/100,0.05);
    xx = [xmin:step_size:xmax];
    
    warning(['Region of support not specfied. Range used between ' num2str(xmin) ' and ' num2str(xmax) ' in ' num2str(step_size) ' step increments. Inspect the pdf.Mean and pdf.multipleroots variables returned to refine interval. Note: if pdfinfo.mean returned is non-sensical, then the density might be unbounded.']);
else 
    xx = varargin{1}; 
end

if (Dm >3)
    root=zeros(length(xx),Dm);
    warning('All roots returned -- isolate correct root manually');
else
    root = zeros(length(xx),1);
end


counter=1;



for x=xx
    r=(roots(sym2poly(subs(Lmz,'z',x))));
    
    if (length(root)==0)
        r=zeros(length(r),1); 
    end
    if (length(r) >3)
        root(counter,1:length(r))=(real(r)+i*imag(r)/pi).';
    else

        r = (r(find(imag(r)>0)));     
        if (length(r)==0)
           r = NaN;
        end 
        root(counter,1) = real(r)+i*imag(r)/pi;
    end
    counter=counter+1;
end


pdfinfo = struct('range',xx,'density',imag(root),'real',real(root),'poles',poles,'multipleroots',PossBdryPts,'mean',Moment1);

    
