function [Luv,varargout] = irreducLuv(Luv,u,v); 
%irreducLuv Makes a bivariate polynomial Luv irreducible
%   [Luv,minimal] = irreducLuv(Luv,u,v) makes Luv irreducible with respect to u and v.
%   
%   Input : Luv, u, v
%   Output: Luv (irreducible format)
%   Optional: minimal (equal to 1 if minimal, 0 if not)
%
%   Disclaimer: This is NOT the minimal representation of the polynomial
%               Sometimes the polynomial may still be factored in which
%               case it is useful to identify the "right factor". When the
%               polynomial encodes a density and the density is compactly
%               supported, this polynomial MUST have an expansion about
%               zero.
%               Thus, if Luv = Luv1 * Luv2 and Luv encodes a density, a
%               test to see the "right factor" is to run
%               Luv2Coeff(Luv1,u) and Luv2Coeff(Luv2,u) -- whichever gives
%               a correct sequence of coefficients is the "right factor"
%               
%   
%   Example:
%       syms m z
%       LmzA = numden(m-0.5/(1-z)-0.5/(2-z));
%       LmzB = irreducLuv(LmzB,m,z);
%       
%
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Wednesday, January 17, 2006.



%1. Clear the denominator after expanding and simplify expression
Luv = numden(simplify(expand(Luv)));

%2. Make Lb(x,y) square free by removing any common factors of x and y
if(diff(Luv,u)~=0)
   Luv = simplify(Luv/maple('gcd',Luv,diff(Luv,u)));
end

if(diff(Luv,v)~=0)
    Luv = simplify(Luv/maple('gcd',Luv,diff(Luv,v)));
end

Lb = Luv;

%3. Check to see if a minimal polynomial can be created
allfactors=maple('factors',Lb);

%4. Discard the scaling factor and count the remaining factors
relevant_factors=maple('op',2,char(allfactors));
number_relevant=str2num(maple('nops',char(relevant_factors))); % Convert from symbolic to numeric

nout = max(nargout,1)-1;

if (number_relevant>1),
    
    if (nout == 0)
        warning('Polynomial can be factored even more; might be useful to identify the correct factor. Type "factor(L)" to see the factorization.')
        Luv = factor(Luv);
    else 
        varargout(1) = {0};
    end
else
    Luv = collect(Luv,u);
    if (nout == 1)
        varargout(1) = {1};
    end
end



